==> taskjuggler_2.3.1.orig.tar.gz: taskjuggler-2.3.1.orig/taskjuggler/TaskDependency.cpp <==
/*
 * TaskDependency.cpp - TaskJuggler
 *
 * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * $Id: TaskDependency.cpp 1259 2006-01-31 12:04:00Z cs $
 */

#include "TaskDependency.h"

#include <assert.h>

#include "Project.h"
#include "Task.h"
#include "Scenario.h"

TaskDependency::TaskDependency(QString tri, int maxScenarios) : taskRefId(tri)
{
    gapDuration = new long[maxScenarios];
    gapLength = new long[maxScenarios];
    taskRef = 0;
    for (int sc = 0; sc < maxScenarios; ++sc)
        gapDuration[sc] = gapLength[sc] = (sc == 0 ? 0 : -1);
}

TaskDependency::~TaskDependency()
{
    delete [] gapDuration;
    delete [] gapLength;
}

long
TaskDependency::getGapDuration(int sc) const
{
    for ( ; ; )
    {
        if (gapDuration[sc] >= 0)
            return gapDuration[sc];
        Project* p = taskRef->getProject();
        Scenario* parent = p->getScenario(sc)->getParent();
        assert(parent);
        sc = p->getScenarioIndex(parent->getId()) - 1;
    }
}

long
TaskDependency::getGapLength(int sc) const
{
    for ( ; ; )
    {
        if (gapLength[sc] >= 0)
            return gapLength[sc];
        Project* p = taskRef->getProject();
        Scenario* parent = p->getScenario(sc)->getParent();
        assert(parent);
        sc = p->getScenarioIndex(parent->getId()) - 1;
    }
}

==> taskjuggler_2.4.0.orig.tar.gz: taskjuggler-2.4.0/taskjuggler/TaskDependency.cpp <==
/*
 * TaskDependency.cpp - TaskJuggler
 *
 * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * $Id: TaskDependency.cpp 1407 2007-02-17 09:46:12Z cs $
 */

#include "TaskDependency.h"

#include <assert.h>

#include "Project.h"
#include "Task.h"
#include "Scenario.h"

TaskDependency::TaskDependency(QString tri, int maxScenarios) :
    taskRefId(tri),
    taskRef(0),
    gapDuration(new long[maxScenarios]),
    gapLength(new long[maxScenarios])
{
    for (int sc = 0; sc < maxScenarios; ++sc)
        gapDuration[sc] = gapLength[sc] = (sc == 0 ? 0 : -1);
}

TaskDependency::~TaskDependency()
{
    delete [] gapDuration;
    delete [] gapLength;
}

long
TaskDependency::getGapDuration(int sc) const
{
    for ( ; ; )
    {
        if (gapDuration[sc] >= 0)
            return gapDuration[sc];
        Project* p = taskRef->getProject();
        Scenario* parent = p->getScenario(sc)->getParent();
        assert(parent);
        sc = p->getScenarioIndex(parent->getId()) - 1;
    }
}

long
TaskDependency::getGapLength(int sc) const
{
    for ( ; ; )
    {
        if (gapLength[sc] >= 0)
            return gapLength[sc];
        Project* p = taskRef->getProject();
        Scenario* parent = p->getScenario(sc)->getParent();
        assert(parent);
        sc = p->getScenarioIndex(parent->getId()) - 1;
    }
}
